@@ -6,9 +6,9 @@ use Moose;
 
 sub default_attributes {
     return {
-        MinChilds => 3,
-        Encode    => 'encode',
-        Decode    => 'decode',
+        MinProcesses => 3,
+        Encode       => 'encode',
+        Decode       => 'decode',
     };
 }
 
@@ -29,12 +29,14 @@ sub job3 : Job {
 
 sub encode {
     my ( $self, $result ) = @_;
-    return "DefaultAttributes::ENCODE::${result}::ENCODE::DefaultAttributes";
+    my $package = ref($self);
+    return "${package}::ENCODE::${result}::ENCODE::${package}";
 }
 
 sub decode {
     my ( $self, $workload ) = @_;
-    return "DefaultAttributes::DECODE::${workload}::DECODE::DefaultAttributes";
+    my $package = ref($self);
+    return "${package}::DECODE::${workload}::DECODE::${package}";
 }
 
 1;
